@@ -321,4 +321,99 @@ var _ = Describe("Config Local", func() {
 		gomega.Expect(err).To(gomega.BeNil())
 		gomega.Expect(config2.Engine.MachineEnabled).To(gomega.Equal(true))
 	})
+
+	It("Rootless networking", func() {
+		// Given
+		config, err := NewConfig("")
+		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(config.Containers.RootlessNetworking).To(gomega.Equal("slirp4netns"))
+		// When
+		config2, err := NewConfig("testdata/containers_default.conf")
+		// Then
+		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(config2.Containers.RootlessNetworking).To(gomega.Equal("cni"))
+	})
+
+	It("default netns", func() {
+		// Given
+		config, err := NewConfig("")
+		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(config.Containers.NetNS).To(gomega.Equal(""))
+		// When
+		config2, err := NewConfig("testdata/containers_default.conf")
+		// Then
+		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(config2.Containers.NetNS).To(gomega.Equal("bridge"))
+	})
+
+	It("should have a default secret driver", func() {
+		// Given
+		path := ""
+		// When
+		config, err := NewConfig(path)
+		gomega.Expect(err).To(gomega.BeNil())
+		// Then
+		gomega.Expect(config.Secrets.Driver).To(gomega.Equal("file"))
+	})
+
+	It("should be possible to override the secret driver and options", func() {
+		// Given
+		path := "testdata/containers_override.conf"
+		// When
+		config, err := NewConfig(path)
+		gomega.Expect(err).To(gomega.BeNil())
+		// Then
+		gomega.Expect(config.Secrets.Driver).To(gomega.Equal("pass"))
+		gomega.Expect(config.Secrets.Opts).To(gomega.Equal(map[string]string{
+			"key":  "foo@bar",
+			"root": "/srv/password-store",
+		}))
+	})
+
+	It("Set machine image path", func() {
+		// Given
+		config, err := NewConfig("")
+		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(config.Machine.Image).To(gomega.Equal("testing"))
+		// When
+		config2, err := NewConfig("testdata/containers_default.conf")
+		// Then
+		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(config2.Machine.Image).To(gomega.Equal("stable"))
+	})
+
+	It("Set machine disk", func() {
+		// Given
+		config, err := NewConfig("")
+		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(config.Machine.DiskSize).To(gomega.Equal(uint64(10)))
+		// When
+		config2, err := NewConfig("testdata/containers_default.conf")
+		// Then
+		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(config2.Machine.DiskSize).To(gomega.Equal(uint64(20)))
+	})
+	It("Set machine CPUs", func() {
+		// Given
+		config, err := NewConfig("")
+		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(config.Machine.CPUs).To(gomega.Equal(uint64(1)))
+		// When
+		config2, err := NewConfig("testdata/containers_default.conf")
+		// Then
+		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(config2.Machine.CPUs).To(gomega.Equal(uint64(2)))
+	})
+	It("Set machine memory", func() {
+		// Given
+		config, err := NewConfig("")
+		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(config.Machine.Memory).To(gomega.Equal(uint64(2048)))
+		// When
+		config2, err := NewConfig("testdata/containers_default.conf")
+		// Then
+		gomega.Expect(err).To(gomega.BeNil())
+		gomega.Expect(config2.Machine.Memory).To(gomega.Equal(uint64(1024)))
+	})
+
 })
